@@ -63,6 +63,8 @@ def search_gdc( args ):
     """
     MANIFEST_FILE = os.path.join(SCRIPT_DIR, "files/gdc/manifest-all-gdc.txt.gz")
     CATEGORIES_FILE = os.path.join(SCRIPT_DIR, 'files/gdc/categories-all-gdc.txt')
+    print('Using manifest file: {}'.format(MANIFEST_FILE))
+    print('Using category file: {}'.format(CATEGORIES_FILE))
     search_results = {}
     # dictionary of search terms: {"general": "...", "tissue": "...", "celltype": "..."...}
     search_dict = atlas_utils.parse_search_terms( args['searchterms'] ) if ('searchterms' in args and args['searchterms'] != '') else {}
@@ -70,6 +72,7 @@ def search_gdc( args ):
         print_gdc_help()
     else:
         search_dict = convert_general_terms( search_dict, CATEGORIES_FILE )
+        print('Search dictionary: {}'.format(str(search_dict)))
         search_results = get_manifest_rows( search_dict, MANIFEST_FILE )
     return search_results
 
@@ -140,6 +143,15 @@ def get_manifest_rows( search_dict, MANIFEST_FILE ):
     # write filtered data frame to output file for download
     df.index.name = 'index'
     df.to_csv(DEFAULT_SEARCH_FILE, sep='\t')
+
+    print(df)
+    print('')
+    print('Number of files found: {}'.format(str(len(df['filename']))))
+    print('Number of unique assays found: {}'.format(str(len(list(set(df['assay']))))))
+    print('Number of tissues-of-origin found: {}'.format(str(len(list(set(df['tissue']))))))
+
+    print('Search results written to {}.'.format(DEFAULT_SEARCH_FILE))
+    print('Type "bioshed download gdc" to download data files or "bioshed download gdc --list" for file info before downloading.')
     return df
 
 def download_gdc( args ):
@@ -192,7 +204,7 @@ def download_gdc( args ):
         print_gdc_help()
     elif os.path.exists(infile):
         df = pd.read_csv(infile, sep='\t')
-        print(df)
+        # print(df)
         if assay != '':
             df = df.loc[df['assay'].str.contains(assay, case=False)]
         if _id != '':
