@@ -1,6 +1,4 @@
 import sys, os, json
-SCRIPT_DIR = str(os.path.dirname(os.path.realpath(__file__)))
-sys.path.append(os.path.join(SCRIPT_DIR))
 import aws_s3_utils
 
 ### supersedes aws_s3_utils and other file utils scripts. ###
